// mbl@lri.fr - 2013 - Simple text chat (client)

// === Communicating with the server ===

// First, import the net module to communicate 
var net = require("net");

// Specify the address of the server
var host = 'localhost';		// default server host
var port = 7000; 			// default port number

// Then, connect to server
var server = net.connect(port, host, function() {
	console.log('Connected to', host+':'+port);
});
server.setEncoding('utf8');		// we read and write text strings

// Set up a handler for displaying the received message
server.on('data', displayMsg);

// Set up a handler for connection errors
server.on('error', function() {
	// Could not connect to the server, say goodbye and quit
	bye('Error with the connection. Bye.');
});

// Set up a handler when the server disconnects
server.on('end', function() {
	// The server died, say goodbye and quit
	bye('Connection closed. Bye.');
});

// === Interacting with the user ===

// Create a stream to read/write on the terminal line by line
var rl = require('readline');
var terminal = rl.createInterface({
		input: process.stdin, 
		output: process.stdout,
		terminal: true
	});


// Set up a handler to send messages typed by the user to the server
terminal.on('line', function(line) {
	server.write(line+'\n');
	terminal.prompt();
});

// Set up a handler to terminate when the user closes the terminal
terminal.on('close', function() {
	bye();
})

// Display a message
function displayMsg(msg) {
	console.log('> '+msg.slice(0, -1)); // trim trailing \n
}

// Quit nicely
function bye(msg) {
	if (msg)
		console.log(msg);
	terminal.close();
	process.exit();
}

// Ready to accept user input
terminal.setPrompt('');
terminal.prompt();

